@@ -14,7 +14,6 @@
 #include <QPaintEvent>
 #include <QPainter>
 #include <QPainterPath>
-#include <QStyle>
 #include <QStyleOptionProgressBar>
 
 #define ROUND_MARGIN 6
@@ -153,6 +152,11 @@ KCapacityBar::DrawTextMode KCapacityBar::drawTextMode() const
 }
 
 void KCapacityBar::drawCapacityBar(QPainter *p, const QRect &rect) const
+{
+    drawCapacityBar(p, rect, {});
+}
+
+void KCapacityBar::drawCapacityBar(QPainter *p, const QRect &rect, QStyle::State state) const
 {
     if (d->ce_capacityBar) {
         QStyleOptionProgressBar opt;
@@ -161,7 +165,7 @@ void KCapacityBar::drawCapacityBar(QPainter *p, const QRect &rect) const
         opt.minimum = 0;
         opt.maximum = 100;
         opt.progress = d->value;
-        opt.state |= QStyle::State_Horizontal;
+        opt.state |= (state | QStyle::State_Horizontal);
         opt.text = d->text;
         opt.textAlignment = Qt::AlignCenter;
         opt.textVisible = !d->text.isEmpty();
