@@ -21,6 +21,7 @@
 #include <QScreen>
 #include <QScrollArea>
 #include <QScrollBar>
+#include <QShowEvent>
 #include <QStyle>
 #include <QStyleOption>
 #include <QTextBrowser>
@@ -158,7 +159,7 @@ KMessageDialog::KMessageDialog(KMessageDialog::Type type, const QString &text, Q
     if ((d->m_type == KMessageDialog::Information) || (d->m_type != KMessageDialog::Error)) {
         // set Ok button
         setButtons();
-    } else if ((d->m_type == KMessageDialog::WarningContinueCancel)) {
+    } else if (d->m_type == KMessageDialog::WarningContinueCancel) {
         // set Continue & Cancel buttons
         setButtons(KStandardGuiItem::cont(), KGuiItem(), KStandardGuiItem::cancel());
     }
@@ -464,7 +465,7 @@ void KMessageDialog::setNotifyEnabled(bool enable)
 
 void KMessageDialog::showEvent(QShowEvent *event)
 {
-    if (d->m_notifyEnabled) {
+    if (d->m_notifyEnabled && !event->spontaneous()) {
         // TODO include m_listWidget items
         beep(d->m_type, d->m_messageLabel->text(), topLevelWidget());
     }
