@@ -18,6 +18,7 @@
 
 #include <ktitlewidget.h>
 
+#include <KLineEditEventHandler>
 #include <QAbstractButton>
 #include <QAbstractItemView>
 #include <QApplication>
@@ -166,6 +167,7 @@ void KPageViewPrivate::rebuildGui()
     if (!hasSearchableView()) {
         layout->removeWidget(searchLineEditContainer);
         searchLineEditContainer->setVisible(false);
+        searchLineEdit->setEnabled(false);
         titleWidget->setAutoFillBackground(false);
         layout->setSpacing(0);
         separatorLine->setVisible(false);
@@ -176,6 +178,7 @@ void KPageViewPrivate::rebuildGui()
                                         q_ptr->style()->pixelMetric(QStyle::PM_LayoutBottomMargin));
     } else {
         titleWidget->setObjectName("KPageView::TitleWidget");
+        searchLineEdit->setEnabled(true);
         searchLineEditContainer->setVisible(true);
         searchLineEditContainer->setSizePolicy(QSizePolicy::Ignored, QSizePolicy::Fixed);
         separatorLine->setVisible(true);
@@ -415,8 +418,6 @@ void KPageViewPrivate::updateTitleWidget(const QModelIndex &index)
 
 void KPageViewPrivate::updateActionsLayout(const QModelIndex &index, const QModelIndex &previous)
 {
-    Q_Q(KPageView);
-
     if (previous.isValid()) {
         const auto previousActions = qvariant_cast<QList<QAction *>>(model->data(index, KPageModel::ActionsRole));
         for (const auto action : previousActions) {
@@ -502,6 +503,7 @@ void KPageViewPrivate::init()
     layout->setRowStretch(3, 1);
 
     searchLineEdit = new QLineEdit(defaultWidget);
+    KLineEditEventHandler::catchReturnKey(searchLineEdit);
     searchTimer.setInterval(400);
     searchTimer.setSingleShot(true);
     searchTimer.callOnTimeout(q, [this] {
