@@ -18,7 +18,6 @@
 int main(int argc, char **argv)
 {
     QApplication::setApplicationName(QStringLiteral("kselectactiontest"));
-    QApplication::setAttribute(Qt::AA_UseHighDpiPixmaps, true);
     QApplication app(argc, argv);
 
     QWidget parentWidget;
@@ -43,13 +42,13 @@ SelectActionTest::SelectActionTest(QWidget *parent)
     m_comboSelect->setToolBarMode(KSelectAction::ComboBoxMode);
     m_comboSelect->setWhatsThis(QStringLiteral("What's this?"));
 
-    connect(m_comboSelect, qOverload<QAction *>(&KSelectAction::triggered), this, &SelectActionTest::actionTriggered);
+    connect(m_comboSelect, &KSelectAction::actionTriggered, this, &SelectActionTest::actionTriggered);
     connect(m_comboSelect, &KSelectAction::indexTriggered, this, &SelectActionTest::indexTriggered);
     connect(m_comboSelect, &KSelectAction::textTriggered, this, &SelectActionTest::textTriggered);
 
     m_buttonSelect->setToolBarMode(KSelectAction::MenuMode);
     m_buttonSelect->setWhatsThis(QStringLiteral("What's this?"));
-    connect(m_buttonSelect, qOverload<QAction *>(&KSelectAction::triggered), this, &SelectActionTest::actionTriggered);
+    connect(m_buttonSelect, &KSelectAction::actionTriggered, this, &SelectActionTest::actionTriggered);
     connect(m_buttonSelect, &KSelectAction::indexTriggered, this, &SelectActionTest::indexTriggered);
     connect(m_buttonSelect, &KSelectAction::textTriggered, this, &SelectActionTest::textTriggered);
 
@@ -101,3 +100,5 @@ void SelectActionTest::slotActionTriggered(bool state)
 {
     qDebug() << sender() << " state " << state;
 }
+
+#include "moc_kselectactiontest.cpp"
